AdminLTE 3 | Editors

# Text Editors

### Summernote

Place <em>some</em> <u>text</u> <strong>here</strong>

### CodeMirror

<div class="info-box bg-gradient-info"> <span class="info-box-icon"><i class="far fa-bookmark"></i></span> <div class="info-box-content"> <span class="info-box-text">Bookmarks</span> <span class="info-box-number">41,410</span> <div class="progress"> <div class="progress-bar" style="width: 70%"></div> </div> <span class="progress-description"> 70% Increase in 30 Days </span> </div> </div>